==> veracity-source-1.0.0.10517.tar.gz: veracity/src/tortoise/vvDialog/vvVerbsDebug.h <==
/*
Copyright 2010-2011 SourceGear, LLC

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

#ifndef VV_VERBS_DEBUG_H
#define VV_VERBS_DEBUG_H

#include "precompiled.h"
#include "vvVerbs.h"


/**
 * A debug implementation of vvVerbs that returns fake information and reports fake progress.
 * This is mostly useful to drive a GUI during development when you want to simulate 
 * realistic data and output, but don't want to actually do anything.
 */
class vvVerbsDebug : public vvVerbs
{
// implementation
public:
	/**
	 * See base class documentation.
	 */
	virtual bool Initialize(
		class vvContext& cContext
		);

	/**
	 * See base class documentation.
	 */
	virtual void Shutdown(
		class vvContext& cContext
		);

	/**
	 * See base class documentation.
	 */
	virtual bool GetLocalRepos(
		class vvContext& cContext,
		wxArrayString&   cLocalRepos
		);

	/**
	 * See base class documentation.
	 */
	virtual bool LocalRepoExists(
		class vvContext& cContext,
		const wxString&  sName
		);

	/**
	 * See base class documentation.
	 */
	virtual bool GetRemoteRepos(
		class vvContext& cContext,
		wxString& sRepoDescriptorName,
		wxArrayString&   cRemoteRepos,
		wxArrayString& cRemoteRepoAliases
		);

	/**
	 * See base class documentation.
	 */
	virtual bool FindWorkingFolder(
		class vvContext& cContext,
		const wxString&  sPath,
		wxString*        pFolder,
		wxString*        pRepo,
		wxArrayString*        pBaselineHIDs = NULL
		);

	/**
	 * See base class documentation.
	 */
	virtual bool FindWorkingFolder(
		class vvContext&     cContext,
		const wxArrayString& cPaths,
		wxString*            pFolder,
		wxString*            pRepo,
		wxArrayString*        pBaselineHIDs = NULL
		);

	/**
	 * See base class documentation.
	 */
	virtual bool GetRepoPath(
		class vvContext& cContext,
		const wxString&  sAbsolutePath,
		const wxString&  sWorkingFolder,
		wxString&        sRepoPath
		);

	/**
	 * See base class documentation.
	 */
	virtual bool GetBranches(
		class vvContext& cContext,
		const wxString&  sRepo,
		bool bIncludeClosed,
		wxArrayString&   cBranches
		);

	/**
	 * See base class documentation.
	 */
	virtual bool GetUsers(
		class vvContext& cContext,
		const wxString&  sRepo,
		stlUserDataList& cUsers
		);

	/**
	 * See base class documentation.
	 */
	virtual bool GetCurrentUser(
		class vvContext& cContext,
		const wxString&  sRepo,
		wxString&        sUser
		);

	/**
	 * See base class documentation.
	 */
	virtual bool GetStamps(
		class vvContext&  cContext,
		const wxString&   sRepo,
		stlStampDataList& cStamps
		);
	virtual bool GetTags(
		class vvContext&  cContext, 
		const wxString&   sRepo,    
		stlTagDataList& cTags   
		);
	/**
	 * See base class documentation.
	 */
	virtual bool GetBranch(
		class vvContext& cContext,
		const wxString&  sFolder,
		wxString&        sBranch
		);

	virtual bool GetColumnPreferences(
		vvContext&     pCtx,
		vvHistoryColumnPreferences& cColumnPrefs
		);

	virtual bool SaveColumnPreferences(
		vvContext&     pCtx,
		vvHistoryColumnPreferences& cColumnPrefs
		);

	virtual bool GetHistoryFilterDefaults(
		vvContext&     pCtx,						
		wxString& sRepoName,
		vvHistoryFilterOptions& cHistoryDefaults	
		);

	/**
	 * See base class documentation.
	 */
	virtual bool New(
		class vvContext& cContext,
		const wxString&  sName,
		const wxString&  sFolder        = wxEmptyString,
		const wxString&  sStorageDriver = wxEmptyString,
		const wxString&  sHashMethod    = wxEmptyString
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Clone(
		class vvContext& cContext,
		const wxString&  sExistingRepo,
		const wxString&  sNewRepoName
		);

	virtual bool Update(
			vvContext&      pCtx,
			const wxString& sFolder,
			CheckoutType    eType,
			const wxString& sTarget
			);
	/**
	 * See base class documentation.
	 */
	virtual bool Checkout(
		class vvContext& cContext,
		const wxString&  sName,
		const wxString&  sFolder,
		CheckoutType     eType,
		const wxString&  sTarget
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Status(
		class vvContext& cContext,
		const wxString&  sFolder,
		const wxString&  sRevision,
		DiffData&        cDiff
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Conflicts(
		class vvContext& cContext,
		const wxString&  sFolder,
		ConflictData&    cConflicts
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Rename(
		class vvContext&      pCtx,					
		const wxString& sFullPath_objectToRename,	
		const wxString& sNewName					
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Commit(
		class vvContext&     cContext,
		const wxString&      sFolder,
		const wxString&      sComment,
		const wxArrayString* pPaths    = NULL,
		const wxArrayString* pStamps   = NULL,
		const wxString*      pUser     = NULL,
		vvFlags              cFlags    = 0u,
		wxString*            pHid      = NULL
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Move(
		class vvContext&      pCtx,					
		const wxArrayString& sFullPath_objectToMove,	
		const wxString& sNewParentPath
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Add(
		class vvContext&      pCtx,					
		const wxArrayString& sFullPath_objectToAdd
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Remove(
		class vvContext&      pCtx,					
		const wxArrayString& sFullPath_objectToRemove
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Pull(
		class vvContext& cContext,						
		const wxString&  sSrcLocalRepoNameOrRemoteURL,		
		const wxString&  sDestLocalRepoName,				
		const wxArrayString& saAreas,										
		const wxArrayString& saTags,					
		const wxArrayString& saDagnodes,
		const wxArrayString& saBranchNames
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Push(
		class vvContext& cContext,						
		const wxString&  sDestLocalRepoNameOrRemoteURL,	
		const wxString&  sSrcLocalRepoName,				
		const wxArrayString& saAreas,										
		const wxArrayString& saTags,					
		const wxArrayString& saDagnodes,
		const wxArrayString& saBranchNames
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Incoming(
		class vvContext& cContext,						//< [in] [out] Error and context info.
		const wxString&  sSrcLocalRepoNameOrRemoteURL,	//< [in] The local repo name, or remote repo URL.  Changes will be pulled from that repo.
		const wxString&  sDestLocalRepoName,			//< [in] The name of the local repo to pull changes into.
		HistoryData& cHistoryData
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Outgoing(
		class vvContext& cContext,						//< [in] [out] Error and context info.
		const wxString&  sDestLocalRepoNameOrRemoteURL,	//< [in] The local repo name, or remote repo URL.  Changes will be pulled from that repo.
		const wxString&  sSrcLocalRepoName,			//< [in] The name of the local repo to pull changes into.
		HistoryData& cHistoryData
		);
	
	virtual bool History(
		class vvContext& cContext,						//< [in] [out] Error and context info.
		const wxString&  sLocalRepoName,				//< [in] The name of the local repo to pull changes into.
		const vvHistoryFilterOptions filterOptions,		//< [in] History Options.
		HistoryData& cHistoryData,						//< [out] History Results
		void ** ppNewHistoryToken						//< [out] A token that can be used to fetch more data.
		);

	virtual bool History__Fetch_More(
		class vvContext& pCtx,							//< [in] [out] Error and context info.
		const wxString&  sLocalRepoName,				//< [in] The name of the local repo to pull changes into.
		unsigned int nNumResultsDesired,				//< [in] The number of additional results desired.
		void * pHistoryToken,							//< [in]  The token that was returned by a previous call to history.  This will be freed if the fetch is successful.
		HistoryData& cHistoryData,						//< [out] The new data.
		void ** ppNewHistoryToken						//< [out] A new token that can be used to fetch more data.
		);

	virtual bool History__Free_Token(
		class vvContext& pCtx,							//< [in] [out] Error and context info.
		void * pHistoryToken);							//< [in] The token to free.

	virtual bool Repo_Item_Get_Children(
		class vvContext& pCtx,							//< [in] [out] Error and context info.
		wxString sRepoName,								//< [in] The name of the local repo 
		wxString sChangesetHID,							//< [in] The changeset to browse
		wxString sItemPath,								//< [in] The full path of the item to look up.  This must be a repo path.
		RepoItemList& cChildren);

	virtual bool Get_Revision_Details(
		class vvContext& pCtx,							//< [in] [out] Error and context info.
		const wxString&  sLocalRepoName,				//< [in] The name of the local repo to pull changes into.
		const wxString& sRevID,							//< [in] The revision to load
		HistoryEntry& cHistoryEntry,						//< [out] The details.
		vvVerbs::RevisionList children						//< [out] A vector of the children of the revision.
		);
// private functionality
private:
	/**
	 * Simulates work by sleeping for a semi-random length of time.
	 * Also reports progress over the course of the sleep time.
	 */
	void SimulateWork(
		class vvContext& cContext,
		unsigned int     uBase,             //< Base number of milliseconds to sleep.
		unsigned int     uSteps     = 0u,   //< Number of steps to report as progress, or zero to not report any.
		float            dVariation = 0.25f //< Percentage to vary the base amount by.
		);
};


#endif

==> veracity-source-1.1.0.10565.tar.gz: veracity/src/tortoise/vvDialog/vvVerbsDebug.h <==
/*
Copyright 2010-2011 SourceGear, LLC

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

#ifndef VV_VERBS_DEBUG_H
#define VV_VERBS_DEBUG_H

#include "precompiled.h"
#include "vvVerbs.h"


/**
 * A debug implementation of vvVerbs that returns fake information and reports fake progress.
 * This is mostly useful to drive a GUI during development when you want to simulate 
 * realistic data and output, but don't want to actually do anything.
 */
class vvVerbsDebug : public vvVerbs
{
// implementation
public:
	/**
	 * See base class documentation.
	 */
	virtual bool Initialize(
		class vvContext& cContext
		);

	/**
	 * See base class documentation.
	 */
	virtual void Shutdown(
		class vvContext& cContext
		);

	/**
	 * See base class documentation.
	 */
	virtual bool GetLocalRepos(
		class vvContext& cContext,
		wxArrayString&   cLocalRepos
		);

	/**
	 * See base class documentation.
	 */
	virtual bool LocalRepoExists(
		class vvContext& cContext,
		const wxString&  sName
		);

	/**
	 * See base class documentation.
	 */
	virtual bool GetRemoteRepos(
		class vvContext& cContext,
		wxString& sRepoDescriptorName,
		wxArrayString&   cRemoteRepos,
		wxArrayString& cRemoteRepoAliases
		);

	/**
	 * See base class documentation.
	 */
	virtual bool FindWorkingFolder(
		class vvContext& cContext,
		const wxString&  sPath,
		wxString*        pFolder,
		wxString*        pRepo,
		wxArrayString*        pBaselineHIDs = NULL
		);

	/**
	 * See base class documentation.
	 */
	virtual bool FindWorkingFolder(
		class vvContext&     cContext,
		const wxArrayString& cPaths,
		wxString*            pFolder,
		wxString*            pRepo,
		wxArrayString*        pBaselineHIDs = NULL
		);

	/**
	 * See base class documentation.
	 */
	virtual bool GetRepoPath(
		class vvContext& cContext,
		const wxString&  sAbsolutePath,
		const wxString&  sWorkingFolder,
		wxString&        sRepoPath
		);

	/**
	 * See base class documentation.
	 */
	virtual bool GetBranches(
		class vvContext& cContext,
		const wxString&  sRepo,
		bool bIncludeClosed,
		wxArrayString&   cBranches
		);

	/**
	 * See base class documentation.
	 */
	virtual bool GetUsers(
		class vvContext& cContext,
		const wxString&  sRepo,
		stlUserDataList& cUsers
		);

	/**
	 * See base class documentation.
	 */
	virtual bool GetCurrentUser(
		class vvContext& cContext,
		const wxString&  sRepo,
		wxString&        sUser
		);

	/**
	 * See base class documentation.
	 */
	virtual bool GetStamps(
		class vvContext&  cContext,
		const wxString&   sRepo,
		stlStampDataList& cStamps
		);
	virtual bool GetTags(
		class vvContext&  cContext, 
		const wxString&   sRepo,    
		stlTagDataList& cTags   
		);
	/**
	 * See base class documentation.
	 */
	virtual bool GetBranch(
		class vvContext& cContext,
		const wxString&  sFolder,
		wxString&        sBranch
		);

	virtual bool GetColumnPreferences(
		vvContext&     pCtx,
		vvHistoryColumnPreferences& cColumnPrefs
		);

	virtual bool SaveColumnPreferences(
		vvContext&     pCtx,
		vvHistoryColumnPreferences& cColumnPrefs
		);

	virtual bool GetHistoryFilterDefaults(
		vvContext&     pCtx,						
		wxString& sRepoName,
		vvHistoryFilterOptions& cHistoryDefaults	
		);

	/**
	 * See base class documentation.
	 */
	virtual bool New(
		class vvContext& cContext,
		const wxString&  sName,
		const wxString&  sFolder        = wxEmptyString,
		const wxString&  sStorageDriver = wxEmptyString,
		const wxString&  sHashMethod    = wxEmptyString
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Clone(
		class vvContext& cContext,
		const wxString&  sExistingRepo,
		const wxString&  sNewRepoName
		);

	virtual bool Update(
			vvContext&      pCtx,
			const wxString& sFolder,
			CheckoutType    eType,
			const wxString& sTarget
			);
	/**
	 * See base class documentation.
	 */
	virtual bool Checkout(
		class vvContext& cContext,
		const wxString&  sName,
		const wxString&  sFolder,
		CheckoutType     eType,
		const wxString&  sTarget
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Status(
		class vvContext& cContext,
		const wxString&  sFolder,
		const wxString&  sRevision,
		DiffData&        cDiff
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Conflicts(
		class vvContext& cContext,
		const wxString&  sFolder,
		ConflictData&    cConflicts
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Rename(
		class vvContext&      pCtx,					
		const wxString& sFullPath_objectToRename,	
		const wxString& sNewName					
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Commit(
		class vvContext&     cContext,
		const wxString&      sFolder,
		const wxString&      sComment,
		const wxArrayString* pPaths    = NULL,
		const wxArrayString* pStamps   = NULL,
		const wxString*      pUser     = NULL,
		vvFlags              cFlags    = 0u,
		wxString*            pHid      = NULL
		);

	virtual bool AddComment(
		class vvContext& cContext, 
		const wxString&  sName,    
		const wxString&  sChangesetHID,  
		const wxString&  sNewComment	
		);

	virtual bool AddStamp(
		class vvContext& cContext, 
		const wxString&  sRepoName,    
		const wxString&  sChangesetHID,  
		const wxString&  sNewStamp
		);
	virtual bool AddTag(
		class vvContext& cContext, 
		const wxString&  sRepoName,    
		const wxString&  sChangesetHID,  
		const wxString&  sNewTag
		);

	virtual bool DeleteStamp(
		class vvContext& pCtx, 
		const wxString&  sRepoName,    
		const wxString&  sChangesetHID,  
		const wxString&  sRemoveMe	
		);

	virtual bool DeleteTag(
		class vvContext& pCtx, 
		const wxString&  sRepoName,    
		const wxString&  sRemoveMe	
		);
	/**
	 * See base class documentation.
	 */
	virtual bool Move(
		class vvContext&      pCtx,					
		const wxArrayString& sFullPath_objectToMove,	
		const wxString& sNewParentPath
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Add(
		class vvContext&      pCtx,					
		const wxArrayString& sFullPath_objectToAdd
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Remove(
		class vvContext&      pCtx,					
		const wxArrayString& sFullPath_objectToRemove
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Pull(
		class vvContext& cContext,						
		const wxString&  sSrcLocalRepoNameOrRemoteURL,		
		const wxString&  sDestLocalRepoName,				
		const wxArrayString& saAreas,										
		const wxArrayString& saTags,					
		const wxArrayString& saDagnodes,
		const wxArrayString& saBranchNames
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Push(
		class vvContext& cContext,						
		const wxString&  sDestLocalRepoNameOrRemoteURL,	
		const wxString&  sSrcLocalRepoName,				
		const wxArrayString& saAreas,										
		const wxArrayString& saTags,					
		const wxArrayString& saDagnodes,
		const wxArrayString& saBranchNames
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Incoming(
		class vvContext& cContext,						//< [in] [out] Error and context info.
		const wxString&  sSrcLocalRepoNameOrRemoteURL,	//< [in] The local repo name, or remote repo URL.  Changes will be pulled from that repo.
		const wxString&  sDestLocalRepoName,			//< [in] The name of the local repo to pull changes into.
		HistoryData& cHistoryData
		);

	/**
	 * See base class documentation.
	 */
	virtual bool Outgoing(
		class vvContext& cContext,						//< [in] [out] Error and context info.
		const wxString&  sDestLocalRepoNameOrRemoteURL,	//< [in] The local repo name, or remote repo URL.  Changes will be pulled from that repo.
		const wxString&  sSrcLocalRepoName,			//< [in] The name of the local repo to pull changes into.
		HistoryData& cHistoryData
		);
	
	virtual bool History(
		class vvContext& cContext,						//< [in] [out] Error and context info.
		const wxString&  sLocalRepoName,				//< [in] The name of the local repo to pull changes into.
		const vvHistoryFilterOptions filterOptions,		//< [in] History Options.
		HistoryData& cHistoryData,						//< [out] History Results
		void ** ppNewHistoryToken						//< [out] A token that can be used to fetch more data.
		);

	virtual bool History__Fetch_More(
		class vvContext& pCtx,							//< [in] [out] Error and context info.
		const wxString&  sLocalRepoName,				//< [in] The name of the local repo to pull changes into.
		unsigned int nNumResultsDesired,				//< [in] The number of additional results desired.
		void * pHistoryToken,							//< [in]  The token that was returned by a previous call to history.  This will be freed if the fetch is successful.
		HistoryData& cHistoryData,						//< [out] The new data.
		void ** ppNewHistoryToken						//< [out] A new token that can be used to fetch more data.
		);

	virtual bool History__Free_Token(
		class vvContext& pCtx,							//< [in] [out] Error and context info.
		void * pHistoryToken);							//< [in] The token to free.

	virtual bool Repo_Item_Get_Children(
		class vvContext& pCtx,							//< [in] [out] Error and context info.
		wxString sRepoName,								//< [in] The name of the local repo 
		wxString sChangesetHID,							//< [in] The changeset to browse
		wxString sItemPath,								//< [in] The full path of the item to look up.  This must be a repo path.
		RepoItemList& cChildren);

	virtual bool Get_Revision_Details(
		class vvContext& pCtx,							//< [in] [out] Error and context info.
		const wxString&  sLocalRepoName,				//< [in] The name of the local repo to pull changes into.
		const wxString& sRevID,							//< [in] The revision to load
		HistoryEntry& cHistoryEntry,						//< [out] The details.
		vvVerbs::RevisionList& children						//< [out] A vector of the children of the revision.
		);

	virtual bool Export_Revision(
		class vvContext& pCtx,							//< [in] [out] Error and context info.
		const wxString&  sLocalRepoName,				//< [in] The name of the local repo to pull changes into.
		const wxString& sRevID,							//< [in] The revision to load
		wxString sLocalOutputPath						//< [in] The local path to output to.
		);
// private functionality
private:
	/**
	 * Simulates work by sleeping for a semi-random length of time.
	 * Also reports progress over the course of the sleep time.
	 */
	void SimulateWork(
		class vvContext& cContext,
		unsigned int     uBase,             //< Base number of milliseconds to sleep.
		unsigned int     uSteps     = 0u,   //< Number of steps to report as progress, or zero to not report any.
		float            dVariation = 0.25f //< Percentage to vary the base amount by.
		);
};


#endif
